@@ -46,7 +46,7 @@ def getUserId(searchName):
         userdictpickle = os.path.join(config.user_dir, "userdict.pickle")
         try:
             _name2id = pickle.load(open(userdictpickle))
-        except (UnpicklingError,IOError,EOFError,ValueError):
+        except (pickle.UnpicklingError,IOError,EOFError,ValueError):
             _name2id = {}
     id = _name2id.get(searchName, None)
     if id is None:
@@ -110,6 +110,7 @@ class User:
          ('show_fancy_diff', lambda _: _('Show fancy diffs')),
          ('wikiname_add_spaces', lambda _: _('Add spaces to displayed wiki names')),
          ('remember_me', lambda _: _('Remember login information forever')),
+         ('want_trivial', lambda _: _('Subscribe to trivial changes')),
          ('disabled', lambda _: _('Disable this account forever')),
     ]
     _transient_fields =  ['id', 'valid', 'may', 'auth_username', 'trusted']
@@ -144,7 +145,7 @@ class User:
         self.trusted = 0
         self.email = ""
         self.edit_rows = config.edit_rows
-        self.edit_cols = 80
+        #self.edit_cols = 80
         self.tz_offset = int(float(config.tz_offset) * 3600)
         self.last_saved = str(time.time())
         self.css_url = ""
@@ -173,6 +174,7 @@ class User:
         self.show_toolbar = 1
         self.show_nonexist_qm = config.nonexist_qm
         self.show_fancy_diff = 1
+        self.want_trivial = 0
         self.remember_me = 1
 
         if not self.id and not self.auth_username:
