@@ -58,7 +58,7 @@ def do_fullsearch(pagename, request, fieldname='value'):
         return
 
     # send title
-    wikiutil.send_title(request, _('Full text search for "%s"') % (needle,))
+    wikiutil.send_title(request, _('Full text search for "%s"') % (needle,), pagename=pagename)
 
     # search the pages
     pagecount, hits = wikiutil.searchPages(needle,
@@ -110,7 +110,7 @@ def do_titlesearch(pagename, request, fieldname='value'):
              msg=_("Please use a more selective search term instead of '%(needle)s'!") % {'needle': needle})
         return
 
-    wikiutil.send_title(request, _('Title search for "%s"') % (needle,))
+    wikiutil.send_title(request, _('Title search for "%s"') % (needle,), pagename=pagename)
 
     try:
         needle_re = re.compile(needle, re.IGNORECASE)
@@ -333,7 +333,6 @@ def do_info(pagename, request):
     def general(page, pagename, request):
         _ = request.getText
 
-        request.write('<div id="content">\n') # start content div
         request.write('<h2>%s</h2>\n' % _('General Information'))
         
         # show page size
@@ -349,7 +348,8 @@ def do_info(pagename, request):
 
         # show attachments (if allowed)
         attachment_info = getHandler('AttachFile', 'info')
-        if attachment_info: attachment_info(pagename, request)
+        if attachment_info:
+            request.write(attachment_info(pagename, request))
 
         # show subscribers
         subscribers = page.getSubscribers(request,  include_self=1, return_users=1)
@@ -373,7 +373,6 @@ def do_info(pagename, request):
             for linkedpage in links:
                 request.write("%s%s " % (Page(linkedpage).link_to(request), ",."[linkedpage == links[-1]]))
             request.write("</p>")
-        request.write('</div>\n') # end content div
 
 
     def history(page, pagename, request):
@@ -381,7 +380,6 @@ def do_info(pagename, request):
         from stat import ST_MTIME, ST_SIZE
         _ = request.getText
 
-        request.write('<div id="content">\n') # start content div
         request.write('<h2>%s</h2>\n' % _('Revision History'))
 
         # generate history list
@@ -515,7 +513,6 @@ def do_info(pagename, request):
         history_table.render()
         request.write('</div>')
         request.write('\n</form>\n')
-        request.write('</div>\n') # end content div
 
 
     _ = request.getText
@@ -613,8 +610,8 @@ def do_revert(pagename, request):
     try:
         savemsg = pg.saveText(oldpg.get_raw_body(), '0',
             stripspaces=0, notify=1, comment=date, action="SAVE/REVERT")
-    except pg.SaveError:
-        savemsg = _("An error occurred while reverting the page.")
+    except pg.SaveError, msg:
+        savemsg = "%s %s" % (msg, _("An error occurred while reverting the page."))
     request.reset()
     pg.send_page(request, msg=savemsg)
     return None
